@@ -1,6 +1,6 @@
 /* Target-dependent code for Xilinx MicroBlaze.
 
-   Copyright (C) 2009-2022 Free Software Foundation, Inc.
+   Copyright (C) 2009-2025 Free Software Foundation, Inc.
 
    This file is part of GDB.
 
@@ -17,13 +17,12 @@
    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
 
-#include "defs.h"
 #include "frame.h"
 #include "inferior.h"
 #include "symtab.h"
 #include "target.h"
 #include "gdbcore.h"
-#include "gdbcmd.h"
+#include "cli/cli-cmds.h"
 #include "symfile.h"
 #include "objfiles.h"
 #include "regcache.h"
@@ -36,9 +35,10 @@
 #include "frame-unwind.h"
 #include "tramp-frame.h"
 #include "linux-tdep.h"
+#include "solib-svr4-linux.h"
 
 static int
-microblaze_linux_memory_remove_breakpoint (struct gdbarch *gdbarch, 
+microblaze_linux_memory_remove_breakpoint (struct gdbarch *gdbarch,
 					   struct bp_target_info *bp_tgt)
 {
   CORE_ADDR addr = bp_tgt->reqstd_address;
@@ -50,6 +50,9 @@ microblaze_linux_memory_remove_breakpoint (struct gdbarch *gdbarch,
   /* Determine appropriate breakpoint contents and size for this address.  */
   bp = gdbarch_breakpoint_from_pc (gdbarch, &addr, &bplen);
 
+  /* Make sure we see the memory breakpoints.  */
+  scoped_restore restore_memory
+    = make_scoped_restore_show_memory_breakpoints (1);
   val = target_read_memory (addr, old_contents, bplen);
 
   /* If our breakpoint is no longer at the address, this means that the
@@ -62,7 +65,7 @@ microblaze_linux_memory_remove_breakpoint (struct gdbarch *gdbarch,
 }
 
 static void
-microblaze_linux_sigtramp_cache (frame_info_ptr next_frame,
+microblaze_linux_sigtramp_cache (const frame_info_ptr &next_frame,
 				 struct trad_frame_cache *this_cache,
 				 CORE_ADDR func, LONGEST offset,
 				 int bias)
@@ -82,7 +85,7 @@ microblaze_linux_sigtramp_cache (frame_info_ptr next_frame,
 
   /* Registers saved on stack.  */
   for (regnum = 0; regnum < MICROBLAZE_BTR_REGNUM; regnum++)
-    trad_frame_set_reg_addr (this_cache, regnum, 
+    trad_frame_set_reg_addr (this_cache, regnum,
 			     gpregs + regnum * MICROBLAZE_REGISTER_SIZE);
   trad_frame_set_id (this_cache, frame_id_build (base, func));
 }
@@ -90,7 +93,7 @@ microblaze_linux_sigtramp_cache (frame_info_ptr next_frame,
 
 static void
 microblaze_linux_sighandler_cache_init (const struct tramp_frame *self,
-					frame_info_ptr next_frame,
+					const frame_info_ptr &next_frame,
 					struct trad_frame_cache *this_cache,
 					CORE_ADDR func)
 {
@@ -100,7 +103,7 @@ microblaze_linux_sighandler_cache_init (const struct tramp_frame *self,
 				   0);
 }
 
-static struct tramp_frame microblaze_linux_sighandler_tramp_frame = 
+static struct tramp_frame microblaze_linux_sighandler_tramp_frame =
 {
   SIGTRAMP_FRAME,
   4,
@@ -123,18 +126,15 @@ microblaze_linux_init_abi (struct gdbarch_info info,
 					microblaze_linux_memory_remove_breakpoint);
 
   /* Shared library handling.  */
-  set_solib_svr4_fetch_link_map_offsets (gdbarch,
-					 linux_ilp32_fetch_link_map_offsets);
+  set_solib_svr4_ops (gdbarch, make_linux_ilp32_svr4_solib_ops);
 
   /* Trampolines.  */
   tramp_frame_prepend_unwinder (gdbarch,
 				&microblaze_linux_sighandler_tramp_frame);
 }
 
-void _initialize_microblaze_linux_tdep ();
-void
-_initialize_microblaze_linux_tdep ()
+INIT_GDB_FILE (microblaze_linux_tdep)
 {
-  gdbarch_register_osabi (bfd_arch_microblaze, 0, GDB_OSABI_LINUX, 
+  gdbarch_register_osabi (bfd_arch_microblaze, 0, GDB_OSABI_LINUX,
 			  microblaze_linux_init_abi);
 }
